@@ -2,16 +2,21 @@
 #this repository contains the full copyright notices and license terms.
 {
     'name': 'Project Revenue',
+    'name_bg_BG': 'Приходи на проект',
     'name_de_DE': 'Projekte Ertrag',
     'name_es_CO': 'Ingresos por proyectos',
     'name_es_ES': 'Beneficio de proyecto',
     'name_fr_FR': 'Revenu des projets',
-    'version': '1.6.0',
+    'version': '2.2.1',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
     'description': '''Add product on timesheet lines.
 Define allowed services for each employees.
+''',
+    'description_bg_BG': '''Модул Приходи на проект:
+    - Позволява добавяне на продукт към редове от график.
+    - Позволява задаване на позволените за всеки служител услуги.
 ''',
     'description_de_DE': '''Projektmodul Ertrag:
     - Ermöglicht das Hinzufügen von Artikeln zu Zeitpositionen.
@@ -39,9 +44,13 @@ Défini par employé quels services sont autorisés.
         'work.xml',
     ],
     'translation': [
-        'de_DE.csv',
-        'es_CO.csv',
-        'es_ES.csv',
-        'fr_FR.csv',
+        'locale/bg_BG.po',
+        'locale/cs_CZ.po',
+        'locale/de_DE.po',
+        'locale/es_CO.po',
+        'locale/es_ES.po',
+        'locale/fr_FR.po',
+        'locale/nl_NL.po',
+        'locale/ru_RU.po',
     ],
 }
